Find your cloud resources by selecting specific facets or by specifying full text search queries.

{$ table.displaying() $}

| Type | Project | Name | Status | Visibility | Updated | Field Matches | Actions
--- | --- | --- | --- | --- | --- | --- | --- | ---
{$ table.queryResponse.statusCode | slQueryStatus $}
| {$ hit._type | slResourceLabeler $} | {$ hit._source.project_id | slKeystoneProjectName | noValue$} |  | {$ hit._source.status | slCommonStatus | noValue $} | {$ hit._type | slCommonVisibility: hit._source:table.userSession.project_id | noValue $} | {$ hit._source.updated_at | date:'short' | noValue $} | {$ hit._type | slResourceLabeler: field $} - |
Results exceeds pagination limit. Please refine your search or increase the limit setting.